==> haskell-hopenpgp-2.7.4.1-71-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.7.4.1
id: hOpenPGP-2.7.4.1-HexPllxtxgA2dOaVUdlzF6
key: hOpenPGP-2.7.4.1-HexPllxtxgA2dOaVUdlzF6
license: MIT
copyright: 2012-2018  Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: https://salsa.debian.org/clint/hOpenPGP
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)
category: Codec, Data
abi: 0c8e92fb0b11c3c48354480c57b12054
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
import-dirs: /usr/lib/ghc-8.6.5/site-local/hOpenPGP-2.7.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hOpenPGP-2.7.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hOpenPGP-2.7.4.1
hs-libraries: HShOpenPGP-2.7.4.1-HexPllxtxgA2dOaVUdlzF6
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq
    asn1-encoding-0.9.5-6xTC56rlj2161Wc0QnpN3c
    attoparsec-0.13.2.2-IYmscZi60PM1VHlw2sOR1C base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm
    bifunctors-5.5.4-F7d4B9ltNTgBiYmBPi0jgL binary-0.8.6.0
    binary-conduit-1.3.1-Fb96tgifhFPFy1cWUEIWLv bytestring-0.10.8.2
    bzlib-0.5.0.5-8TMEZNLRAIMKxXCedq0SW1
    conduit-1.3.1.1-5tT7brArM8HFpf8jCW5Sg8
    conduit-extra-1.3.1.1-1GijJTiXD8TCsMw9tkQ4yM containers-0.6.0.1
    crypto-cipher-types-0.0.9-EDnaq2zDyKz77VO2aVXtii
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    errors-2.3.0-KiwfkgZwA0gLNGsJTA97Fg
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    incremental-parser-0.3.2.2-NgSJKY9OCO2prsWeKgkDS
    ixset-typed-0.4.0.1-DIEcNRm1VJH4EBYyyA4u8w
    lens-4.17.1-HTmXQinx68g2x0Owmg0yAK
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA
    nettle-0.3.0-2fnPd9woiMI99sXNZlCUqu
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    newtype-0.2.1.0-9Kg8oHCEa4KHY86ixQzh8L
    openpgp-asciiarmor-0.1.1-JQumsxincdaB6CREB3YkyF
    prettyprinter-1.3.0-DFtPOWQpUL1DRfMvM9ilsI
    resourcet-1.2.2-1jEybJ3raWeJ8zv1YiemYn
    split-0.2.3.3-7ukSI7OZicINGuE3hgII text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hopenpgp-2.7.4.1-72-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hopenpgp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hOpenPGP
version: 2.7.4.1
id: hOpenPGP-2.7.4.1-36hFyCslfKrE74m3Fg3QSU
key: hOpenPGP-2.7.4.1-36hFyCslfKrE74m3Fg3QSU
license: MIT
copyright: 2012-2018  Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: https://salsa.debian.org/clint/hOpenPGP
synopsis: native Haskell implementation of OpenPGP (RFC4880)
description:
    native Haskell implementation of OpenPGP (RFC4880), plus Camellia (RFC5581), plus ECC (RFC6637)
category: Codec, Data
abi: ae57df77579b93df2d8bd6ca0bac688c
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.CFB Codec.Encryption.OpenPGP.Compression
    Codec.Encryption.OpenPGP.Expirations
    Codec.Encryption.OpenPGP.Fingerprint
    Codec.Encryption.OpenPGP.KeyInfo
    Codec.Encryption.OpenPGP.KeySelection
    Codec.Encryption.OpenPGP.KeyringParser
    Codec.Encryption.OpenPGP.Ontology Codec.Encryption.OpenPGP.S2K
    Codec.Encryption.OpenPGP.SecretKey
    Codec.Encryption.OpenPGP.Serialize
    Codec.Encryption.OpenPGP.Signatures Codec.Encryption.OpenPGP.Types
    Data.Conduit.OpenPGP.Compression Data.Conduit.OpenPGP.Decrypt
    Data.Conduit.OpenPGP.Filter Data.Conduit.OpenPGP.Keyring
    Data.Conduit.OpenPGP.Keyring.Instances Data.Conduit.OpenPGP.Verify
hidden-modules: Codec.Encryption.OpenPGP.Internal
                Codec.Encryption.OpenPGP.Internal.CryptoCipherTypes
                Codec.Encryption.OpenPGP.Internal.Cryptonite
                Codec.Encryption.OpenPGP.Internal.HOBlockCipher
                Codec.Encryption.OpenPGP.SerializeForSigs
                Codec.Encryption.OpenPGP.Types.Internal.Base
                Codec.Encryption.OpenPGP.Types.Internal.CryptoniteNewtypes
                Codec.Encryption.OpenPGP.Types.Internal.PacketClass
                Codec.Encryption.OpenPGP.Types.Internal.PKITypes
                Codec.Encryption.OpenPGP.Types.Internal.Pkt
                Codec.Encryption.OpenPGP.Types.Internal.PrettyUtils
                Codec.Encryption.OpenPGP.Types.Internal.TK
                Codec.Encryption.OpenPGP.BlockCipher
import-dirs: /usr/lib/ghc-8.6.5/site-local/hOpenPGP-2.7.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hOpenPGP-2.7.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hOpenPGP-2.7.4.1
hs-libraries: HShOpenPGP-2.7.4.1-36hFyCslfKrE74m3Fg3QSU
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq
    asn1-encoding-0.9.5-6xTC56rlj2161Wc0QnpN3c
    attoparsec-0.13.2.2-IYmscZi60PM1VHlw2sOR1C base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm
    bifunctors-5.5.4-F7d4B9ltNTgBiYmBPi0jgL binary-0.8.6.0
    binary-conduit-1.3.1-CQxXKy9tT9NJWOzyL0QJnR bytestring-0.10.8.2
    bzlib-0.5.0.5-8TMEZNLRAIMKxXCedq0SW1
    conduit-1.3.1.1-Jmotk7FVIoVB29sd5GQrbo
    conduit-extra-1.3.1.1-KarPsJJ3pX1C3TTl91JHev containers-0.6.0.1
    crypto-cipher-types-0.0.9-EDnaq2zDyKz77VO2aVXtii
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    errors-2.3.0-KiwfkgZwA0gLNGsJTA97Fg
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    incremental-parser-0.3.2.2-89VBl54Mp5GLwBwTTD48Sv
    ixset-typed-0.4.0.1-DIEcNRm1VJH4EBYyyA4u8w
    lens-4.17.1-4Jk5GSd1SEYIuq2Vm9OfL2
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA
    nettle-0.3.0-2fnPd9woiMI99sXNZlCUqu
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    newtype-0.2.1.0-9Kg8oHCEa4KHY86ixQzh8L
    openpgp-asciiarmor-0.1.1-JQumsxincdaB6CREB3YkyF
    prettyprinter-1.3.0-DFtPOWQpUL1DRfMvM9ilsI
    resourcet-1.2.2-1jEybJ3raWeJ8zv1YiemYn
    split-0.2.3.3-7ukSI7OZicINGuE3hgII text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-hopenpgp/html/hOpenPGP.haddock
haddock-html: /usr/share/doc/haskell-hopenpgp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
